#!/bin/bash

# This helper script will generate a self-signed cert suitable for dev/test scenarios
# and store it in a target namespace with a given secret name.  Within the secret
# are 3 keys (filenames) that can be mounted and wired up to dependent services
#
# certSan argument should be suitable to feed directly into the cert request:
# "DNS:example.com,DNS:www.example.net,IP:10.0.0.1"
#
# /scripts/gen-certs.sh
#

# TODO: There doesn't seem to be a remove certs script

set -e
set -x

source /scripts/utils.sh

check_access ${appsNamespace} secrets

secretName=${namingPrefix}-cert

kubectl --namespace ${infraNamespace} delete secret ${secretName} --ignore-not-found

echo "Generating self signed certificate"

umask 077

cd /tmp

cat <<EOF >req.cfg
[req]
distinguished_name=req
[san]
subjectAltName="DNS:*.${appsNamespace}.svc.cluster.local,DNS:*.${infraNamespace}.svc.cluster.local"
EOF

openssl req -x509 \
  -nodes \
  -newkey rsa:4096 \
  -keyout ec-key.pem \
  -out ec-cert.pem \
  -subj "/CN=*.svc.cluster.local" \
  -extensions san \
  -config req.cfg \
  -days 365

echo "Storing cert in Secret ${secretName} in namespace ${infraNamespace}"
kubectl --namespace ${infraNamespace} create secret generic ${secretName} \
  --from-file=ec-key.pem=./ec-key.pem \
  --from-file=ec-cert.pem=./ec-cert.pem

rm -f ./ec-key.pem ./ec-cert.pem

cprint "$0 done "