#!/bin/bash

# This helper script will handle generation of a secret in the app namespace
#
# /scripts/gen-user-secret.sh
#

set -e

source /scripts/utils.sh

check_access ${infraNamespace} secrets
check_access ${appsNamespace} secrets

cprint "Checking for secret.."
if /scripts/wait-until -t 30 -i 5 true kubectl --namespace "${appsNamespace}" get secret "${dbUserCredsSecretPassName}"; then
  cprint "Secret ${dbUserCredsSecretPassName} already exists."
else
  echo "No secret found.. Generating new account."
  password=$(gen_password)
  if [ ${awsDeployment} == "true" ]; then
    echo "Setting the token for elasticache."
    run_cmd aws elasticache modify-replication-group \
    --region ${awsDefaultRegion} \
    --replication-group-id ${replicationGroupId} \
    --auth-token ${password} \
    --auth-token-update-strategy ROTATE \
    --apply-immediately
  fi
  echo "Creating kubernetes secret ${dbUserCredsSecretPassName}"
  run_cmd kubectl --namespace "${appsNamespace}" create secret generic "${dbUserCredsSecretPassName}" --from-literal=password="${password}"
  run_cmd kubectl --namespace "${infraNamespace}" create secret generic "${dbUserCredsSecretPassName}" --from-literal=password="${password}"
  echo "Syncing seed token with new password"
  run_cmd kubectl --namespace "${infraNamespace}" delete secret ${dbPrimaryCredsSecretName} --ignore-not-found
  run_cmd kubectl --namespace "${infraNamespace}" create secret generic "${dbPrimaryCredsSecretName}" --from-literal=password="${password}"
fi


print_header "$0 done."
